@@ -310,7 +310,7 @@ class SelfAttention(layers.Layer):
             sn = self.norm(kqs)
         else:
             sn = kqs
-        out = tf.matmul(sn, self.pm(vv), transpose_b=True)
+        out = tf.matmul(sn, vv, transpose_b=True)
 
         if self.units is not None:
             out = tf.matmul(out, self.scale)
@@ -352,7 +352,7 @@ class MultiHeadSelfAttention(layers.Layer):
     :param final_relu: Boolean, whether to apply a ReLU to the output of the final Dense layer.
     """
     def __init__(self, heads, units=None, norm=None, mh_normalize=True,
-            final_relu=False, positional_encoding=False, **kwargs):
+            final_relu=False, **kwargs):
         super(MultiHeadSelfAttention, self).__init__(**kwargs)
         self.heads=heads
         self.units = units
@@ -363,7 +363,6 @@ class MultiHeadSelfAttention(layers.Layer):
         for _ in range(0,self.heads):
             self.mhsa.append(SelfAttention(units=self.units, norm=self.norm))
         self.cc = layers.Concatenate(axis=1)
-        self.pm = layers.Permute((2,1))
         if self.mh_normalize is True:
             self.ln1 = layers.LayerNormalization()
             self.ln2 = layers.LayerNormalization()
@@ -393,8 +392,10 @@ class MultiHeadSelfAttention(layers.Layer):
     def call(self, inputs):
         xa=[]
         for i in range(0, self.heads):
-            xa.append(self.pm(self.mhsa[i](inputs)+inputs))
-        x=self.pm(self.cc(xa))
+            xa.append(self.mhsa[i](inputs)+inputs)
+            # xa.append(self.pm(self.mhsa[i](inputs)+inputs))
+        # x=self.pm(self.cc(xa))
+        x=self.cc(xa)
         if self.mh_normalize is True:
             x = self.ln1(x)
         xt = tf.matmul(x, self.w_heads)
@@ -426,8 +427,7 @@ class PositionalEncoding(layers.Layer):
         angle_rates = 1 / np.power(10000, (2 * (i//2)) / np.float32(d_model))
         return pos * angle_rates
 
-    @staticmethod
-    def _positional_encoding(position, d_model):
+    def _positional_encoding(self, position, d_model):
         angle_rads = PositionalEncoding._get_angles(np.arange(position)[:, np.newaxis],
                                                         np.arange(d_model)[np.newaxis, :],
                                                         d_model)
